@@ -180,7 +180,7 @@ class Tortoise:
                         key_fk_object = deepcopy(related_model._meta.pk)
                         fk_object.to_field_instance = related_model._meta.pk
                         fk_object.to_field = related_model._meta.pk_attr
-
+                    fk_object.field_type = fk_object.to_field_instance.field_type
                     key_field = f"{field}_id"
                     key_fk_object.pk = False
                     key_fk_object.unique = False
@@ -246,6 +246,8 @@ class Tortoise:
                         o2o_object.to_field_instance = related_model._meta.pk
                         o2o_object.to_field = related_model._meta.pk_attr
 
+                    o2o_object.field_type = o2o_object.to_field_instance.field_type
+
                     key_field = f"{field}_id"
                     key_o2o_object.pk = o2o_object.pk
                     key_o2o_object.index = o2o_object.index
@@ -610,7 +612,7 @@ class Tortoise:
         for r in routers:
             if isinstance(r, str):
                 try:
-                    module_name, class_name = r.rsplit(".", 2)
+                    module_name, class_name = r.rsplit(".", 1)
                     router_cls.append(getattr(importlib.import_module(module_name), class_name))
                 except Exception:
                     raise ConfigurationError(f"Can't import router from `{r}`")
@@ -708,4 +710,4 @@ def run_async(coro: Coroutine) -> None:
         loop.run_until_complete(Tortoise.close_connections())
 
 
-__version__ = "0.17.4"
+__version__ = "0.17.5"
