@@ -66,6 +66,9 @@ class QuerySetSingle(Protocol[T_co]):
     def prefetch_related(self, *args: Union[str, Prefetch]) -> "QuerySetSingle[MODEL]":
         ...  # pragma: nocoverage
 
+    def select_related(self, *args: str) -> "QuerySetSingle[Model]":
+        ...  # pragma: nocoverage
+
     def annotate(self, **kwargs: Function) -> "QuerySetSingle[MODEL]":
         ...  # pragma: nocoverage
 
@@ -392,6 +395,7 @@ class QuerySet(AwaitableQuery[MODEL]):
             .order_by('name', '-tournament__name')
 
         Supports ordering by related models too.
+        A '-' before the name will result in descending sort order, default is ascending.
 
         :raises FieldError: If unknown field has been provided.
         """
@@ -814,7 +818,9 @@ class QuerySet(AwaitableQuery[MODEL]):
         return self.query
 
     def _make_query(self) -> None:
+        # clean tmp records first
         self._select_related_idx = []
+        self._joined_tables = []
         table = self.model._meta.basetable
         if self._fields_for_select:
             append_item = (self.model, len(self._fields_for_select), table, self.model)
